@@ -85,6 +85,8 @@ class FstTable : public IFstTable
 
   	void SetDoubleColumn(IDoubleColumn * doubleColumn, int colNr);
 
+  	IByteBlockColumn* add_byte_block_column(unsigned col_nr);
+
   	void SetFactorColumn(IFactorColumn* factorColumn, int colNr);
 
     void SetColNames();
@@ -106,6 +108,8 @@ class FstTable : public IFstTable
 
     double* GetDoubleWriter(unsigned int colNr);
 
+    IByteBlockColumn* GetByteBlockWriter(unsigned int col_nr);
+
     IStringWriter* GetLevelWriter(unsigned int colNr);
 
     IStringWriter* GetColNameWriter();
