@@ -55,8 +55,8 @@ inline unsigned int StoreCharBlock_v6(ofstream& myfile, IStringWriter* blockRunn
 
 
 inline unsigned int storeCharBlockCompressed_v6(ofstream& myfile, IStringWriter* blockRunner, unsigned int startCount,
-                                                unsigned int endCount, StreamCompressor* intCompressor, StreamCompressor* charCompressor, unsigned short int& algoInt,
-                                                unsigned short int& algoChar, int& intBufSize, int blockNr)
+  unsigned int endCount, StreamCompressor* intCompressor, StreamCompressor* charCompressor, unsigned short int& algoInt,
+  unsigned short int& algoChar, int& intBufSize, int blockNr)
 {
   // Determine string lengths
   unsigned int nrOfElements = endCount - startCount; // the string at position endCount is not included
@@ -102,14 +102,17 @@ inline unsigned int storeCharBlockCompressed_v6(ofstream& myfile, IStringWriter*
 
 void fdsWriteCharVec_v6(ofstream& myfile, IStringWriter* stringWriter, int compression, StringEncoding stringEncoding)
 {
-  unsigned long long vecLength = stringWriter->vecLength; // expected to be larger than zero
+  uint64_t vecLength = stringWriter->vecLength; // expected to be larger than zero
 
-  unsigned long long curPos = myfile.tellp();
-  unsigned long long nrOfBlocks = (vecLength - 1) / BLOCKSIZE_CHAR; // number of blocks minus 1
+  // nothing to write
+  if (vecLength == 0) return;
+
+  uint64_t curPos = myfile.tellp();
+  uint64_t nrOfBlocks = (vecLength - 1) / BLOCKSIZE_CHAR; // number of blocks minus 1
 
   if (compression == 0)
   {
-    unsigned int metaSize = CHAR_HEADER_SIZE + (nrOfBlocks + 1) * 8;
+    uint32_t metaSize = CHAR_HEADER_SIZE + (nrOfBlocks + 1) * 8;
 
     // first CHAR_HEADER_SIZE bytes store compression setting and block size
     std::unique_ptr<char[]> metaP(new char[metaSize]);
@@ -119,24 +122,24 @@ void fdsWriteCharVec_v6(ofstream& myfile, IStringWriter* stringWriter, int compr
     memset(meta, 0, metaSize);
 
     // Set column header
-    unsigned int* isCompressed = reinterpret_cast<unsigned int*>(meta);
-    unsigned int* blockSizeChar = reinterpret_cast<unsigned int*>(&meta[4]);
+    uint32_t* isCompressed = reinterpret_cast<uint32_t*>(meta);
+    uint32_t* blockSizeChar = reinterpret_cast<uint32_t*>(&meta[4]);
     *blockSizeChar = BLOCKSIZE_CHAR; // check why 2047 and not 2048
     *isCompressed = stringEncoding << 1;
 
     myfile.write(meta, metaSize); // write block offset index
 
-    unsigned long long* blockPos = reinterpret_cast<unsigned long long*>(&meta[CHAR_HEADER_SIZE]);
-    unsigned long long fullSize = metaSize;
+    uint64_t* blockPos = reinterpret_cast<uint64_t*>(&meta[CHAR_HEADER_SIZE]);
+    uint64_t fullSize = metaSize;
 
-    for (unsigned long long block = 0; block < nrOfBlocks; ++block)
+    for (uint64_t block = 0; block < nrOfBlocks; ++block)
     {
-      unsigned int totSize = StoreCharBlock_v6(myfile, stringWriter, block * BLOCKSIZE_CHAR, (block + 1) * BLOCKSIZE_CHAR);
+      uint32_t totSize = StoreCharBlock_v6(myfile, stringWriter, block * BLOCKSIZE_CHAR, (block + 1) * BLOCKSIZE_CHAR);
       fullSize += totSize;
       blockPos[block] = fullSize;
     }
 
-    unsigned int totSize = StoreCharBlock_v6(myfile, stringWriter, nrOfBlocks * BLOCKSIZE_CHAR, vecLength);
+    uint32_t totSize = StoreCharBlock_v6(myfile, stringWriter, nrOfBlocks * BLOCKSIZE_CHAR, vecLength);
     fullSize += totSize;
     blockPos[nrOfBlocks] = fullSize;
 
@@ -150,7 +153,7 @@ void fdsWriteCharVec_v6(ofstream& myfile, IStringWriter* stringWriter, int compr
 
   // Use compression
 
-  unsigned int metaSize = CHAR_HEADER_SIZE + (nrOfBlocks + 1) * CHAR_INDEX_SIZE; // 1 long and 2 unsigned int per block
+  uint32_t metaSize = CHAR_HEADER_SIZE + (nrOfBlocks + 1) * CHAR_INDEX_SIZE; // 1 long and 2 unsigned int per block
 
   std::unique_ptr<char[]> metaP(new char[metaSize]);
   char* meta = metaP.get();
@@ -159,8 +162,8 @@ void fdsWriteCharVec_v6(ofstream& myfile, IStringWriter* stringWriter, int compr
   memset(meta, 0, metaSize);
 
   // Set column header
-  unsigned int* isCompressed = reinterpret_cast<unsigned int*>(meta);
-  unsigned int* blockSizeChar = reinterpret_cast<unsigned int*>(&meta[4]);
+  uint32_t* isCompressed = reinterpret_cast<uint32_t*>(meta);
+  uint32_t* blockSizeChar = reinterpret_cast<uint32_t*>(&meta[4]);
   *blockSizeChar = BLOCKSIZE_CHAR;
   *isCompressed = (stringEncoding << 1) | 1; // set compression flag
 
@@ -323,6 +326,9 @@ inline void ReadDataBlockCompressed_v6(istream& myfile, IStringColumn* blockRead
 void fdsReadCharVec_v6(istream& myfile, IStringColumn* blockReader, unsigned long long blockPos, unsigned long long startRow,
   unsigned long long vecLength, unsigned long long size)
 {
+  // nothing to read
+  if (vecLength == 0) return;
+
   // Jump to startRow size
   myfile.seekg(blockPos);
 
