@@ -32,13 +32,13 @@ class IColumnFactory
 {
 public:
   virtual ~IColumnFactory() {};
-  virtual IFactorColumn*  CreateFactorColumn(int nrOfRows, int nrOfLevels, FstColumnAttribute columnAttribute) = 0;
-  virtual ILogicalColumn* CreateLogicalColumn(int nrOfRows, FstColumnAttribute columnAttribute) = 0;
-  virtual IDoubleColumn* CreateDoubleColumn(int nrOfRows, FstColumnAttribute columnAttribute, short int scale) = 0;
-  virtual IIntegerColumn* CreateIntegerColumn(int nrOfRows, FstColumnAttribute columnAttribute, short int scale) = 0;
-  virtual IByteColumn* CreateByteColumn(int nrOfRows, FstColumnAttribute columnAttribute) = 0;
-  virtual IInt64Column* CreateInt64Column(int nrOfRows, FstColumnAttribute columnAttribute, short int scale) = 0;
-  virtual IStringColumn* CreateStringColumn(int nrOfRows, FstColumnAttribute columnAttribute) = 0;
+  virtual IFactorColumn*  CreateFactorColumn(uint64_t nrOfRows, uint64_t nrOfLevels, FstColumnAttribute columnAttribute) = 0;
+  virtual ILogicalColumn* CreateLogicalColumn(uint64_t nrOfRows, FstColumnAttribute columnAttribute) = 0;
+  virtual IDoubleColumn* CreateDoubleColumn(uint64_t nrOfRows, FstColumnAttribute columnAttribute, short int scale) = 0;
+  virtual IIntegerColumn* CreateIntegerColumn(uint64_t nrOfRows, FstColumnAttribute columnAttribute, short int scale) = 0;
+  virtual IByteColumn* CreateByteColumn(uint64_t nrOfRows, FstColumnAttribute columnAttribute) = 0;
+  virtual IInt64Column* CreateInt64Column(uint64_t nrOfRows, FstColumnAttribute columnAttribute, short int scale) = 0;
+  virtual IStringColumn* CreateStringColumn(uint64_t nrOfRows, FstColumnAttribute columnAttribute) = 0;
   virtual IStringArray* CreateStringArray() = 0;
 };
 
