@@ -1,8 +1,9 @@
 
 context("subsetting and compression")
 
-suppressMessages(library(bit64))
-suppressMessages(library(nanotime))
+
+require(bit64)
+require(nanotime)
 
 
 # Clean testdata directory
@@ -15,61 +16,62 @@ if (!file.exists("FactorStore")) {
 # Create a pool of strings
 nroflevels <- 8
 
-char_vec <- function(nrofrows) {
-  sapply(1:nrofrows, function(x) {
+char_vec <- function(nr_of_rows) {
+  sapply(1:nr_of_rows, function(x) {
     paste(sample(LETTERS, sample(1:4)), collapse = "")
   }
   ) }
 
-char_veclong <- function(nrofrows) {
-  sapply(1:nrofrows,
+char_veclong <- function(nr_of_rows) {
+  sapply(1:nr_of_rows,
     function(x) {
       paste(sample(LETTERS, sample(20:25)), collapse = "")
     }
     ) }
 
-date_vec <- function(nrofrows) {
-  date_vec <- sample(1:nrofrows, replace = TRUE)
+date_vec <- function(nr_of_rows) {
+  date_vec <- sample(1:nr_of_rows, replace = TRUE)
   class(date_vec) <- c("IDate", "Date")
   date_vec
 }
 
-difftime_vec <- function(nrOfrows, mode = "double") {
-  vec <- (Sys.time() + 1:nrofrows) - Sys.time()
+difftime_vec <- function(nr_of_rows, mode = "double") {
+  vec <- (Sys.time() + 1:nr_of_rows) - Sys.time()
   mode(vec) <- mode
   vec
 }
 
 # Sample data
-nrofrows <- 10000L
-char_na <- char_vec(nrofrows)
-char_na[sample(1:nrofrows, 10)] <- NA
+nr_of_rows <- 10000L
+char_na <- char_vec(nr_of_rows)
+char_na[sample(1:nr_of_rows, 10)] <- NA
 datatable <- data.frame(
-  Xint = 1:nrofrows,
-  Ylog = sample(c(TRUE, FALSE, NA), nrofrows, replace = TRUE),
-  Zdoub = rnorm(nrofrows),
-  Qchar = char_vec(nrofrows),
-  WFact = factor(sample(char_vec(nroflevels), nrofrows, replace = TRUE)),
-  Ordered = ordered(sample(char_vec(nroflevels), nrofrows, replace = TRUE)),
+  Xint = 1:nr_of_rows,
+  Ylog = sample(c(TRUE, FALSE, NA), nr_of_rows, replace = TRUE),
+  Zdoub = rnorm(nr_of_rows),
+  Qchar = char_vec(nr_of_rows),
+  WFact = factor(sample(char_vec(nroflevels), nr_of_rows, replace = TRUE)),
+  Ordered = ordered(sample(char_vec(nroflevels), nr_of_rows, replace = TRUE)),
   char_na = char_na,
-  CharLong = char_veclong(nrofrows),
-  Date = date_vec(nrofrows),
-  DateDouble = as.Date("2015-01-01") + 1:nrofrows,
-  Integer64 = as.integer64(sample(c(2345612345679, 10, 8714567890), nrofrows, replace = TRUE)),
-  Nanotime = nanotime(sample(1000000:2000000, nrofrows, replace = TRUE)),
-  Raw = as.raw(sample(0:255, nrofrows, replace = TRUE)),
-  Difftime = difftime_vec(nrofrows),
-  DiffTime_int = difftime_vec(nrofrows, "integer"),
+  CharLong = char_veclong(nr_of_rows),
+  Date = date_vec(nr_of_rows),
+  DateDouble = as.Date("2015-01-01") + 1:nr_of_rows,
+  Integer64 = as.integer64(sample(c(2345612345679, 10, 8714567890), nr_of_rows, replace = TRUE)),
+  Nanotime = nanotime(sample(1000000:2000000, nr_of_rows, replace = TRUE)),
+  Raw = as.raw(sample(0:255, nr_of_rows, replace = TRUE)),
+  Difftime = difftime_vec(nr_of_rows),
+  DiffTime_int = difftime_vec(nr_of_rows, "integer"),
   stringsAsFactors = FALSE)
 
 # A write / read cylce for a range of columns and rows
-test_write_read <- function(col, from = 1L, to = nrofrows, sel_columns = NULL, compress = 0L, tot_length = nrofrows) {
+test_write_read <- function(col, from = 1L, to = nr_of_rows, sel_columns = NULL, compress = 0L,
+  tot_length = nr_of_rows) {
   dt <- datatable[1:tot_length, col, drop = FALSE]
 
   fstwriteproxy(dt, "FactorStore/data1.fst", compress)  # use compression
 
   # Read full dataset
-  to <- min(to, nrofrows)
+  to <- min(to, nr_of_rows)
   data <- fstreadproxy("FactorStore/data1.fst", columns = sel_columns, from = from, to = to)
 
   if (is.null(sel_columns)) {
@@ -82,8 +84,8 @@ test_write_read <- function(col, from = 1L, to = nrofrows, sel_columns = NULL, c
 
   uneq <- sub_dt[, 1] != data[, 1]
   difftable <- sub_dt
-  difftable$Row <- 1:nrow(difftable)
-  difftable$Other <- data[, 1]
+  difftable[, "Row"] <- seq_len(nrow(difftable))
+  difftable[, "Other"] <- data[, 1]
 
   message <- paste(
     "args: col:", col, "| from:", from, "| to:", to, "| setColumns:", sel_columns,
@@ -99,10 +101,10 @@ test_write_read <- function(col, from = 1L, to = nrofrows, sel_columns = NULL, c
   expect_equal(sub_dt, data, info = message)
 }
 
-colNames <- colnames(datatable)
+col_names <- colnames(datatable)
 
 test_that("Single uncompressed vectors", {
-  sapply(colNames,
+  sapply(col_names,
     function(x) {
       test_write_read(x)
     })
@@ -110,14 +112,14 @@ test_that("Single uncompressed vectors", {
 
 
 test_that("Small uncompressed vectors", {
-  sapply(colNames, function(x){
+  sapply(col_names, function(x) {
     test_write_read(x, to = 30L, tot_length = 30L)
   })
 })
 
 
 test_that("Single weakly compressed vectors", {
-  sapply(colNames,
+  sapply(col_names,
     function(x) {
       test_write_read(x, compress = 30L)
     })
@@ -125,7 +127,7 @@ test_that("Single weakly compressed vectors", {
 
 
 test_that("Single small weakly compressed vectors", {
-  sapply(colNames,
+  sapply(col_names,
     function(x) {
       test_write_read(x, to = 30L, tot_length = 30L, compress = 30L)
     })
@@ -133,7 +135,7 @@ test_that("Single small weakly compressed vectors", {
 
 
 test_that("Single medium sized weakly compressed vectors", {
-  sapply(colNames,
+  sapply(col_names,
     function(x) {
       test_write_read(x, to = 8193L, tot_length = 8193L, compress = 30L)
     })
@@ -141,7 +143,7 @@ test_that("Single medium sized weakly compressed vectors", {
 
 
 test_that("Single moderate compressed vectors", {
-  sapply(colNames,
+  sapply(col_names,
     function(x) {
       test_write_read(x, compress = 60L)
     })
@@ -149,7 +151,7 @@ test_that("Single moderate compressed vectors", {
 
 
 test_that("Single small moderate compressed vectors", {
-  sapply(colNames,
+  sapply(col_names,
     function(x) {
       test_write_read(x, to = 30L, tot_length = 30L, compress = 60L)
   })
@@ -159,7 +161,7 @@ test_that("Single small moderate compressed vectors", {
 # Various boundary conditions
 
 blocktests <- function(col, block_start, block_end, compression) {
-  last_row <- min(block_end * block_size + block_size - 1L, nrofrows)
+  last_row <- min(block_end * block_size + block_size - 1L, nr_of_rows)
   test_write_read(col, 1L + block_start * block_size,      last_row,       NULL, compression)  # full
   test_write_read(col, 1L + block_start * block_size + 4L, last_row,       NULL, compression)  # offset
   test_write_read(col, 1L + block_start * block_size,      last_row - 10L, NULL, compression)  # remainder
@@ -168,19 +170,19 @@ blocktests <- function(col, block_start, block_end, compression) {
 
 blocktestsingletype <- function(type) {
   # Single first block
-  blocktests(type, 0, 0, 0L )  # uncompressed
+  blocktests(type, 0, 0, 0L)  # uncompressed
   blocktests(type, 0, 0, 40L)  # algorithm 1
   blocktests(type, 0, 0, 80L)  # algorithm 2
 
   # Single middle block
-  blocktests(type, 1, 1, 0L )  # uncompressed
+  blocktests(type, 1, 1, 0L)  # uncompressed
   blocktests(type, 1, 1, 40L)  # algorithm 1
   blocktests(type, 1, 1, 80L)  # algorithm 2
 
-  last_block <- as.integer( (nrofrows - 1) / block_size)
+  last_block <- as.integer((nr_of_rows - 1) / block_size)  ## nolint
 
   # Single last block
-  blocktests(type, last_block, last_block, 0L )  # uncompressed
+  blocktests(type, last_block, last_block, 0L)  # uncompressed
   blocktests(type, last_block, last_block, 40L)  # algorithm 1
   blocktests(type, last_block, last_block, 80L)  # algorithm 2
 
